<?php

/*
 * Plugin Name: Shopinext
 * Description: Shopinext Ödeme Modülü
 * Version: 1.0.0
 * Author: Shopinext
 * Author URI: https://www.shopinext.com
 * Domain Path: /languages/
 */

if (!defined('ABSPATH')) {
    exit;
}

error_reporting(0);

global $shopinext_version;
$shopinext_version = '1.0';
register_deactivation_hook(__FILE__, 'shopinext_deactivation');
register_activation_hook(__FILE__, 'shopinext_activate');
add_action('plugins_loaded', 'shopinext_update_check');

function shopinext_update_check() {
    global $shopinext_version;
    global $wpdb;
    $installed_ver = get_option("$shopinext_version");
    if ($installed_ver != $shopinext_version) {
        shopinext_update();
    }
}

function shopinext_update() {
    global $shopinext_version;
    update_option("shopinext_version", $shopinext_version);
}

function shopinext_activate() {
    global $wpdb;
    global $shopinext_version;
    $shopinext_version = '1.0';

    $charset_collate = $wpdb->get_charset_collate();
    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

    add_option('shopinext_version', $shopinext_version);
}

function shopinext_deactivation() {
    global $wpdb;
    global $shopinext_version;

    delete_option('shopinext_version');
    flush_rewrite_rules();
}

function shopinext_install_data() {
    global $wpdb;
}


add_action('plugins_loaded', 'woocommerce_shopinext', 0);

function woocommerce_shopinext() {

    if (!class_exists('WC_Payment_Gateway'))
        return;

    class WC_Shopinext_Gateway extends WC_Payment_Gateway {

        public function __construct() {


            $this->id = 'shopinext';
            $this->method_title = __('Shopinext', 'shopinext');
            $this->method_description = __('Shopinext Payment Module', 'shopinext');
            $this->icon = plugins_url('/shopinext/images/cards.png', dirname(__FILE__));
            $this->has_fields = false;
            $this->supports = array('products', 'refunds');
            $this->init_form_fields();
            $this->init_settings();
            $this->shopinext_kullanici_adi = $this->settings['shopinext_kullanici_adi'];
            $this->shopinext_api = $this->settings['shopinext_api'];
            $this->shopinext_parola = $this->settings['shopinext_parola'];
            $this->title = $this->settings['title'];
            $this->description = $this->settings['description'];
            $this->enabled = $this->settings['enabled'];
            $this->order_button_text = $this->settings['button_title'];
            add_action('init', array(&$this, 'check_shopinext'));
            add_action('woocommerce_api_wc_shopinext_gateway', array($this, 'check_shopinext'));
            add_action('admin_notices', array($this, 'checksFields'));
            if (version_compare(WOOCOMMERCE_VERSION, '2.0.0', '>=')) {
                add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));
            } else {
                add_action('woocommerce_update_options_payment_gateways', array($this, 'process_admin_options'));
            }
            add_action('woocommerce_receipt_shopinext', array($this, 'receipt_page'));
        }

        function checksFields() {
            global $woocommerce;

            if ($this->enabled == 'no')
                return;
        }

        function init_form_fields() {
            $this->form_fields = array(
                'shopinext_api' => array(
                    'title' => __('Shopinext API Key', 'shopinext'),
                    'type' => 'text',
                    'desc_tip' => __('API key Given by Shopinext', 'shopinext'),
                ),
                'shopinext_kullanici_adi' => array(
                    'title' => __('Shopinext Username', 'shopinext'),
                    'type' => 'text',
                    'desc_tip' => __('Username Given by Shopinext', 'shopinext'),
                ),
                'shopinext_parola' => array(
                    'title' => __('Shopinext Password', 'shopinext'),
                    'type' => 'text',
                    'desc_tip' => __('Password Given by Shopinext', 'shopinext'),
                ),
                'title' => array(
                    'title' => __('Method Title', 'shopinext'),
                    'type' => 'text',
                    'desc_tip' => __('This title will show to customers during checkout', 'shopinext'),
                    'default' => 'Shopinext İle Ödeyin'
                ),
                'description' => array(
                    'title' => __('Description', 'shopinext'),
                    'type' => 'text',
                    'description' => __('The description which the user sees during checkout', 'shopinext'),
                    'default' => __('Pay with your credit card via Shopinext', 'shopinext'),
                    'desc_tip' => true,
                ),
                'button_title' => array(
                    'title' => __('Checkout Button', 'shopinext'),
                    'type' => 'text',
                    'description' => __('Checkout Button', 'shopinext'),
                    'default' => __('Complete Order', 'shopinext'),
                    'desc_tip' => true,
                )
            );
        }

        public function admin_options() {

            $shopinexturl = plugins_url() . '/shopinext/';
            echo '<img src="' . $shopinexturl . 'images/logo.png" width="250px"/><hr/>';
            echo '<table class="form-table">';
            $this->generate_settings_html();
            echo '</table>';
        }




       function GetSession($order_id) {
            global $woocommerce;
            if (version_compare(get_bloginfo('version'), '4.5', '>='))
                wp_get_current_user();
            else
                get_currentuserinfo();
            $order = new WC_Order($order_id);

            $ip = $_SERVER['REMOTE_ADDR'];
            $billing_full_name = $order->get_billing_first_name() .' '. $order->get_billing_last_name();
            $billing_full_name = !empty($billing_full_name) ? $billing_full_name : "NOT PROVIDED";
            $phone = !empty($order->get_billing_phone()) ? $order->get_billing_phone() : 'NOT PROVIDED';
            $email = !empty($order->get_billing_email()) ? $order->get_billing_email() : 'NOT PROVIDED';
            $city_buyer=WC()->countries->states[$order->get_billing_country()][$order->get_billing_state()];
            $city = !empty($city_buyer) ? $city_buyer : 'NOT PROVIDED';
            $ship_city_buyer=WC()->countries->states[$order->get_shipping_country()][$order->get_shipping_state()];
            $ship_city = !empty($ship_city_buyer) ? $ship_city_buyer : 'NOT PROVIDED';
            $shipping_country = $order->get_shipping_country();
            $billing_country = $order->get_billing_country();
            $shipping_postcode = $order->get_shipping_postcode();
            $billing_postcode = $order->get_billing_postcode();
            $billing_address = $order->get_billing_address_1() .' '. $order->get_billing_address_2();
            $shipping_address = $order->get_shipping_address_1() .' '. $order->get_shipping_address_2();
            $shipping_country2 = !empty($shipping_country) ? $shipping_country : 'NOT PROVIDED';
            $billing_country2 = !empty($billing_country) ? $billing_country : 'NOT PROVIDED';
            $shipping_postcode2 = !empty($shipping_postcode) ? $shipping_postcode : 'NOT PROVIDED';
            $billing_postcode2 = !empty($billing_postcode) ? $billing_postcode : 'NOT PROVIDED';
            $billing_address2 = !empty($billing_address) ? $billing_address : 'NOT PROVIDED';
            $shipping_address2 = !empty($shipping_address) ? $shipping_address : 'NOT PROVIDED';
			$allow = array('TRY','USD','EUR');
            $order_amount = $order->get_total();
			if (!in_array($order->get_currency(), $allow)) {
                $output	= [
					"errorMsg"=>"Sadece USD, EUR ve TRY para birimleri için işlem yapabilirsiniz.", 
					"responseMsg"=>"Reddedildi"
				];
				return $output;
            } else {
				if($order->get_currency() !== 'TRY') {
					$data = array(
						'ACTION'=>'CURRENCY',
						'SNID' => $this->shopinext_kullanici_adi,
						'APIKEY' => $this->shopinext_api,
						'SNPASS' => $this->shopinext_parola,
						'CURRENCY'=>$order->get_currency()
					);
					$ch=curl_init();
					curl_setopt($ch, CURLOPT_URL, "https://www.shopinext.com/api/v1");
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_POST, 1) ;
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
					curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
					curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
					curl_setopt($ch, CURLOPT_TIMEOUT, 20);
					$result = json_decode(curl_exec($ch));
					if(curl_errno($ch))
						die("Bağlantı hatası. err:".curl_error($ch));
					curl_close($ch);    
					if(isset($result->amount)) {
						$order_amount = $order_amount * $result->amount;
					}
				}

		$data = array(
			'ACTION'=>'SESSIONTOKEN',
			'APIKEY'=>$this->shopinext_api, // Shopinext API Key - Test Ortamında Gerekmez
			'SNID'=>$this->shopinext_kullanici_adi, // Shopinext Mail Adresiniz - Test Ortamı Kullanıcı Adı
			'SNPASS'=>$this->shopinext_parola, // Shopinext Şifreniz - Test Ortamı Şifre
			'PRICE'=>round($order_amount, 2), // İşlem Tutarı - Kuruş aralığında nokta olmalı, virgül ile ayrılan kısım dahil olmaz.
			'RETURNURL'=>$order->get_checkout_payment_url(true), // Geri Dönüş Sayfası
			'CUSTOMERNAME'=>$billing_full_name, // Alıcı Adı Soyadı
			'CUSTOMEREMAIL'=>$email, // Alıcı Mail Adresi
			'CUSTOMERIP'=>$_SERVER['REMOTE_ADDR'], // Alıcı IP Adresi
			'CUSTOMERUSERAGENT'=>$_SERVER['HTTP_USER_AGENT'],
			'CUSTOMERPHONE'=>$phone, // Alıcı Telefon Numarası
			'BILLTOADDRESSLINE'=>$billing_address2, // Fatura Adresi
			'BILLTOCITY'=>$city, // Fatura Şehir
			'BILLTOCOUNTRY'=>$billing_country2,
			'BILLTOPOSTALCODE'=>$billing_postcode2, // Posta Kodu
			'BILLTOPHONE'=>$phone, // Fatura Telefon Numarası
			'SHIPTOADDRESSLINE'=>$shipping_address2, // Alıcı Adresi
			'SHIPTOCITY'=>$ship_city , // Alıcı Şehir
			'SHIPTOCOUNTRY'=>$shipping_country2,
			'SHIPTOPOSTALCODE'=>$shipping_postcode2, // Posta Kodu
			'SHIPTOPHONE' =>$phone
					);

	$ch=curl_init();
		curl_setopt($ch, CURLOPT_URL, "https://www.shopinext.com/api/v1");
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_POST, 1) ;
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
		curl_setopt($ch, CURLOPT_TIMEOUT, 20);
		$result = json_decode(curl_exec($ch));
		if(curl_errno($ch))
			die("Bağlantı hatası. err:".curl_error($ch));
		curl_close($ch);
		return $result;
	}
}


        function receipt_page($orderid) {

            if(!isset($_POST['responseCode'])){
				global $woocommerce;
				$order = new WC_Order($orderid);
				$status = $order->get_status();
				$showtotal = $order->get_total();
				$currency=$order->get_currency();
				$text_credit_card =__('Credit Cart Form', 'shopinext');
				$session = $this->GetSession($orderid);
				if(isset($session->sessionToken)) {
					
				} else {
				$error_message = $session['errorMsg'];
				}
				include(dirname(__FILE__) . '/shopinext.php');
			}

         if(isset($_POST['responseCode']))
            {
              if($_POST['responseCode']==00){


  $token = $_POST['sessionToken'] ;

          $data = array(
              'ACTION'=>'ISDONE',
              'SESID'=>$token
          );  $ch=curl_init();
          curl_setopt($ch, CURLOPT_URL, "https://www.shopinext.com/api/v1");
          curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
          curl_setopt($ch, CURLOPT_POST, 1) ;
          curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
          curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
          curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
          curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
          curl_setopt($ch, CURLOPT_TIMEOUT, 20);
          $result = json_decode(curl_exec($ch));
          if(curl_errno($ch))
              die("Bağlantı hatası. err:".curl_error($ch));
          curl_close($ch);
          $session = $result;


      if(isset($session->responseCode) && $session->responseCode == 00 ) {


                                       global $woocommerce;
              $error_message = false;
              $order = new WC_Order($orderid);
              $status = $order->get_status();


                                      $post_data = get_post_meta($order_id,'_post_data',true);

                                      update_post_meta($order_id,'_post_data',array());
                                                  if($order->status != 'processing'){

                                                  $order ->status ='Processing';
                                                  $order->payment_complete();

                                                  $order -> add_order_note('Shopinext Payment Gateway <br>Response message :'.$_POST['responseMsg'].'<br>Payment ID :'.$_POST['orderID'].'<br>Session Token :'.$_POST['sessionToken'].'<br>Response Code:'.$_POST['responseCode'].'');

                                                  add_post_meta( $order->id, '_paymentid', sanitize_text_field( $_POST['PaymentID'] ) );
                                                  add_post_meta( $order->id, '_trno', sanitize_text_field( $_POST['TransactionID'] ) );
                                                  $woocommerce -> cart -> empty_cart();
                                                  wp_redirect( $order->get_checkout_order_received_url());

                                              }
                                  }
                   else {

                                                  if($order->status != 'failed'){
                                                  $order ->status ='failed';
                                  echo "Payment failed!<br><br><br>Possible Error : ".$_POST['responseMsg']."<br>PaymentID: ".$_POST['orderID']."<br><br><br>We request you to save these details for further reference. <br>You can always pay for this order by clicking on your name in the top right corner and visiting your orders section."; }
                  }
               }
              else {

                                                  if($order->status != 'failed'){
                                                  $order ->status ='failed';
                                  echo "Payment failed!<br><br><br>Possible Error : ".$_POST['responseMsg']."<br>PaymentID: ".$_POST['orderID']."<br><br><br>We request you to save these details for further reference. <br>You can always pay for this order by clicking on your name in the top right corner and visiting your orders section."; }
                  }

              }



          }

        function process_payment($order_id) {
             global $woocommerce;
             $order = new WC_Order( $order_id );


            if (version_compare(WOOCOMMERCE_VERSION, '2.1.0', '>=')) {
                /* 2.1.0 */
                $checkout_payment_url = $order->get_checkout_payment_url(true);
            } else {
                /* 2.0.0 */
                $checkout_payment_url = get_permalink(get_option('woocommerce_pay_page_id'));
            }

            return array(
                'result' => 'success',
                'redirect' => $checkout_payment_url,
            );
        }

    }

}

add_filter('woocommerce_payment_gateways', 'woocommerce_add_shopinext_gateway');

function woocommerce_add_shopinext_gateway($methods) {
    $methods[] = 'WC_Shopinext_Gateway';
    return $methods;
}

function shopinext_load_plugin_textdomain() {
    load_plugin_textdomain('shopinext', FALSE, plugin_basename(dirname(__FILE__)) . '/languages/');
}

add_action('plugins_loaded', 'shopinext_load_plugin_textdomain');
